v1.2.1
=======
- Updated :func:`rohub.ros_add_annotations` and :func:`ResearchObject.add_annotations` functions to accept a new parameter: `body_specification_file`.
- Fixed bug that caused `ResearchObject` instances to throw errors reloaded after modifications to `editors` or `readers`.
- Renamed `rohub.ros_list_copyright` into `rohub.ros_list_copyright_holders` and `ResearchObject.list_copyright` into `ResearchObject.list_copyright_holders`.
- added functions: 
    * :func:`rohub.query_sparql_endpoint`
    * :func:`rohub.ros_delete_authors`
    * :func:`ResearchObject.delete_authors`
    * :func:`rohub.ros_delete_contributors`
    * :func:`ResearchObject.delete_contributors`
    * :func:`rohub.ros_list_publishers`
    * :func:`rohub.ros_delete_publishers`
    * :func:`ResearchObject.list_publishers`
    * :func:`ResearchObject.delete_publishers`
    * :func:`rohub.ros_delete_copyright_holders`
    * :func:`ResearchObject.delete_copyright_holders`
